"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const common_1 = require("@nestjs/common");
class ElasticsearchService {
    constructor(client, config) {
        this.client = client;
        this.config = config;
    }
    hasIndex() {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { statusCode } = yield this.client.indices.exists({
                    index: this.config.index,
                });
                return statusCode === 200;
            }
            catch (error) {
                common_1.Logger.error(error.message, error.stack);
                return false;
            }
        });
    }
    getIndexStats() {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { body } = yield this.client.indices.stats({
                    index: this.config.index,
                });
                return body;
            }
            catch (error) {
                common_1.Logger.error(error.message, error.stack);
                return false;
            }
        });
    }
    createIndex() {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { body } = yield this.client.indices.create({
                    index: this.config.index,
                    body: {
                        settings: this.config.settings,
                        mappings: {
                            properties: this.config.properties,
                        },
                    },
                });
                return body;
            }
            catch (error) {
                common_1.Logger.error(error.message, error.stack);
                return false;
            }
        });
    }
    updateIndex() {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { body } = yield this.client.indices.putMapping({
                    index: this.config.index,
                    body: {
                        properties: this.config.properties,
                    },
                });
                return body;
            }
            catch (error) {
                common_1.Logger.error(error.message, error.stack);
                return false;
            }
        });
    }
    deleteIndex() {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { body } = yield this.client.indices.delete({
                    index: this.config.index,
                });
                return body;
            }
            catch (error) {
                common_1.Logger.error(error.message, error.stack);
                return false;
            }
        });
    }
    indexDocument(id, document) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { body } = yield this.client.index({
                    index: this.config.index,
                    body: document,
                    id: `${id}`,
                });
                return body;
            }
            catch (error) {
                common_1.Logger.error(error.message, error.stack);
                return false;
            }
        });
    }
    bulkIndexDocuments(documents) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { body } = yield this.client.bulk({
                    index: this.config.index,
                    body: documents,
                });
                return body;
            }
            catch (error) {
                common_1.Logger.error(error.message, error.stack);
                return false;
            }
        });
    }
    deleteDocument(id) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const { body } = yield this.client.delete({
                    index: this.config.index,
                    id: `${id}`,
                });
                return body;
            }
            catch (error) {
                common_1.Logger.error(error.message, error.stack);
                return false;
            }
        });
    }
}
exports.ElasticsearchService = ElasticsearchService;
